package SeMeet::Controller::Invites;
use Mojo::Base 'Mojolicious::Controller', -signatures;

use Data::Random qw(rand_chars);

sub create($c) {
    $c->openapi->valid_input or return;
    my $args = $c->req->json;

#### TODO: VALIDATE EMAIL

    my $meet = $c->schema->resultset('Meet')->find({ id => $args->{meet_id} });
    return $c->error(404, 'NOT_FOUND') if ! $meet;

    my $roles = $meet->user_roles($c->stash->{user}, []);
    if ( ! ($roles->{moderator} || $roles->{owner}) ) {
        return $c->error(403, 'ACCESS_DENIED');
    }

    my $token = rand_chars( set => 'upperalpha', size => 8 );

    my $guard  = $c->schema->txn_scope_guard;

        my $invite = $c->schema->resultset('Invite')->create({
            token       => $token,
            user_id     => $c->stash->{user}->id,
            meet_id     => $meet->id,
            email       => $args->{email},
            displayname => $args->{displayname},
        });

    $guard->commit;

    $invite = $c->schema->resultset('Invite')->find({
        id => $invite->id
    });

    $c->trace(\'User %s create invite form meet "%s" with id %d',
        $c->stash->{user}->username,
        $meet->name,
        $invite->id,
    );

    $c->render(
        status  => 201,
        openapi => $c->spec_filter(
            { $invite->get_columns },
            'Invite',
        )
    );
}

sub meet($c) {
    my $invite = $c->schema->resultset('Invite')->search({
        token  => uc($c->stash->{token}),
#        expire => {'>' => \'now()'}, # zatim nebudeme limitovat casove
    })->first;

    if ( ! $invite ) {
        # TODO: ochrana proti hledani
        $c->render('invalid_invite');
        return;
    }

    my $meet = $c->schema->resultset('Meet')->find({
        id => $invite->meet_id,
    });

    return $c->error(404, 'NOT_FOUND') if ! $meet;

    $c->stash->{meet}  = $meet;
    $c->stash->{token} = $invite->meet_token($meet, $c->config);

    $c->render('meet_guest');
}

1;
