package SeMeet::Controller::Records;
use Mojo::Base 'Mojolicious::Controller', -signatures;

use constant FILENAME_REGEX => qr/(.+)_(\d{4})\-(\d{2})\-(\d{2})\-(\d{2})\-(\d{2})\-(\d{2})\.mp4/;

sub create($c) {
    $c->openapi->valid_input or return;
    my $args = $c->req->json;

    # datum meetu
    if ($args->{file} !~ FILENAME_REGEX) {
        return $c->error(400, 'INVALID FILENAME');
    }
    my $recorded = "$2-$3-$4 $5:$6:$7";

    # Duplicita id
    my $exists = $c->schema->resultset('Record')->count({
        deleted => undef,
        uuid    => $args->{uuid},
    });
    return $c->error(400, 'DUPLICTE UUID') if $exists;

    # meet
    my $meet_uuid = $args->{meeting_url};
    $meet_uuid =~ s/.+\///;
    my $meet = $c->schema->resultset('Meet')->search({
        uuid => $meet_uuid
    })->first;

    return $c->error(400, 'MEET NOT FOUND') if ! $meet;

    my $guard  = $c->schema->txn_scope_guard;

        $meet->add_to_records({
            uuid     => $args->{uuid},
            file     => $args->{file},
            recorded => $recorded,
        });

    $guard->commit;

#    $c->trace(\'Record %s create meet "%s" with id %d',
#        $c->stash->{user}->username,
#        $meet->name,
#        $meet->id,
#    );

    $c->render( status  => 204, text => '' );
}

sub delete($c) {
    $c->openapi->valid_input or return;

    my $record = $c->_get($c->stash->{id}, 1) // return;

    $record->update({ deleted => \'now()' });

    $c->render( status  => 204, text => '' );
}

sub _get($c, $id, $access) {

    my $record = $c->schema->resultset('Record')->find({ id => $id });
    return $c->error(404, 'NOT_FOUND') if ! $record;

    my $roles = $record->meet->user_roles($c->stash->{user}, $c->stash->{groups});
    return $c->error(403, 'ACCESS_DENIED') if ! $roles->{any};

    if ( $access == 1 && ! ($roles->{moderator} || $roles->{owner}) ) {
        return $c->error(403, 'ACCESS_DENIED');
    }

    if ( $access == 2 && ! $roles->{owner} ) {
        return $c->error(403, 'ACCESS_DENIED');
    }

    return $record;
}
1;
